==> zxing-cpp-1.0.7.tar.gz: zxing-cpp-1.0.7/core/src/aztec/AZReader.cpp <==
/*
* Copyright 2016 Nu-book Inc.
* Copyright 2016 ZXing authors
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

#include "aztec/AZReader.h"
#include "aztec/AZDetector.h"
#include "aztec/AZDetectorResult.h"
#include "aztec/AZDecoder.h"
#include "Result.h"
#include "BitMatrix.h"
#include "BinaryBitmap.h"
#include "DecoderResult.h"
#include "DecodeHints.h"

namespace ZXing {
namespace Aztec {

Result
Reader::decode(const BinaryBitmap& image) const
{
	auto binImg = image.getBlackMatrix();
	if (binImg == nullptr) {
		return Result(DecodeStatus::NotFound);
	}

	DetectorResult detectResult = Detector::Detect(*binImg, false);
	DecoderResult decodeResult = DecodeStatus::NotFound;
	std::vector<ResultPoint> points;
	if (detectResult.isValid()) {
		points = detectResult.points();
		decodeResult = Decoder::Decode(detectResult);
	}
	if (!decodeResult.isValid()) {
		detectResult = Detector::Detect(*binImg, true);
		if (detectResult.isValid()) {
			points = detectResult.points();
			decodeResult = Decoder::Decode(detectResult);
		}
	}

	return Result(std::move(decodeResult), std::move(points), BarcodeFormat::AZTEC);
}

} // Aztec
} // ZXing

==> zxing-cpp_1.1.1.orig.tar.gz: zxing-cpp-1.1.1/core/src/aztec/AZReader.cpp <==
/*
* Copyright 2016 Nu-book Inc.
* Copyright 2016 ZXing authors
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

#include "AZReader.h"
#include "AZDetector.h"
#include "AZDetectorResult.h"
#include "AZDecoder.h"

#include <memory>
#include <utility>
#include <vector>
#include "Result.h"
#include "BinaryBitmap.h"
#include "DecoderResult.h"

namespace ZXing {
namespace Aztec {

Result
Reader::decode(const BinaryBitmap& image) const
{
	auto binImg = image.getBlackMatrix();
	if (binImg == nullptr) {
		return Result(DecodeStatus::NotFound);
	}

	DetectorResult detectResult = Detector::Detect(*binImg, false);
	DecoderResult decodeResult = DecodeStatus::NotFound;
	if (detectResult.isValid()) {
		decodeResult = Decoder::Decode(detectResult);
	}

	//TODO: don't start detection all over again, just to swap 2 corner points
	if (!decodeResult.isValid()) {
		detectResult = Detector::Detect(*binImg, true);
		if (detectResult.isValid()) {
			decodeResult = Decoder::Decode(detectResult);
		}
	}

	return Result(std::move(decodeResult), std::move(detectResult).position(), BarcodeFormat::AZTEC);
}

} // Aztec
} // ZXing
